import React, { useState } from 'react';
import { Button } from '@graphpolaris/shared/lib/components/buttons';
import { useDialogContext } from '@graphpolaris/shared/lib/components/layout/Dialog';
import { Input } from '@graphpolaris/shared/lib/components/inputs';
import { TableUI } from '@graphpolaris/shared/lib/components/tableUI/TableUI';
import { useUsersPolicy } from '@graphpolaris/shared/lib/data-access/store';
import { useDispatch } from 'react-redux';
import { setUsersPolicy, UserPolicy } from '@graphpolaris/shared/lib/data-access/store/authorizationUsersSlice';
interface UserManagementContentProps {
  sessionId: string;
  onConfirm: (users: { name: string; email: string; type: string }[]) => void;
  onClickShareLink: () => void;
}

interface FieldConfig<T> {
  key: keyof T;
  label: string;
  type: 'text' | 'dropdown';
  required?: boolean;
}

export const UserManagementContent: React.FC<UserManagementContentProps> = ({ sessionId, onConfirm, onClickShareLink }) => {
  const { setOpen } = useDialogContext();
  const dispatch = useDispatch();

  // !FIXME: This should definited at high level
  const optionsTypeUser = ['', 'Creator', 'Viewer'];
  const [copiedAccessOption, setCopiedAccessOption] = useState<string>(optionsTypeUser[2]);

  const usersPolicy = useUsersPolicy();
  // !FIXME: This should be populated from the store
  const userFields = [
    { key: 'name', label: 'Name', type: 'text', required: true },
    { key: 'email', label: 'Email', type: 'text', required: true },
    { key: 'type', label: 'Type', type: 'dropdown', required: true },
  ] as FieldConfig<UserPolicy>[];

  const options = {
    type: optionsTypeUser,
  };

  const handleUserChange = (newUsers: UserPolicy[]) => {
    dispatch(setUsersPolicy({ users: newUsers }));
  };

  const handleCancel = () => {
    setOpen(false);
  };

  const handleClickShare = () => {
    setOpen(false);
    onClickShareLink();
  };

  return (
    <div className="flex flex-col w-[50rem] h-[40rem]">
      <div className="flex-grow justify-center p-2 text-sm overflow-hidden text-ellipsis whitespace-nowrap">
        <h1 className="flex justify-center font-bold gap-x-1">
          <span>Manage Users Sharing of</span> <span className="text-secondary-500">{sessionId}</span>
        </h1>
      </div>

      <div className="flex flex-row items-center justify-center gap-2 mt-4 w-full">
        <span>By sharing this link recipient will have </span>
        <div>
          <Input
            type="dropdown"
            label=""
            value={copiedAccessOption}
            options={optionsTypeUser}
            onChange={(value) => setCopiedAccessOption(value.toString())}
          />
        </div>
        <span>access</span>
        <Button variant="solid" size="md" label="Copy link" onClick={handleClickShare} />
      </div>

      <div className="flex items-center my-4">
        <hr className="flex-grow border-t border-gray-300" />
        <span className="mx-4 text-gray-500">or</span>
        <hr className="flex-grow border-t border-gray-300" />
      </div>

      <div className="flex flex-col items-center flex-grow mt-4">
        <TableUI data={usersPolicy.users} fieldConfigs={userFields} dropdownOptions={options} onDataChange={handleUserChange} />
      </div>

      <div className="flex justify-center p-2 mt-auto">
        <div className="flex space-x-4">
          <Button variant="outline" size="md" label="Cancel" onClick={handleCancel} />
          <Button variantType="primary" size="md" label="Confirm" onClick={() => onConfirm(usersPolicy.users)} />
        </div>
      </div>
    </div>
  );
};
